NAME

Desktop::KDE::Util::Klipper - Utilities related to Klipper, the KDE clipboard service

VERSION

This document describes version 0.001 of Desktop::KDE::Util::Klipper (from Perl distribution Desktop-KDE-Util), released on 2026-06-17.

SYNOPSIS

DESCRIPTION

FUNCTIONS

klipper_available

Usage:

klipper_available() -> bool

Check whether klipper is available.

Note that even though klipper is available, it can be disabled.

Use klipper_enabled() routine to check whether klipper is enabled.

This function is not exported by default, but exportable.

No arguments.

Return value: (bool)

klipper_enabled

Usage:

klipper_enabled() -> bool

Check whether klipper is enabled.

See also: klipper_available().

This function is not exported by default, but exportable.

No arguments.

Return value: (bool)

HOMEPAGE

Please visit the project's homepage at https://metacpan.org/release/Desktop-KDE-Util.

SOURCE

Source repository is at https://github.com/perlancar/perl-Desktop-KDE-Util.

SEE ALSO

AUTHOR

perlancar <perlancar@cpan.org>

CONTRIBUTING

To contribute, you can send patches by email/via RT, or send pull requests on GitHub.

Most of the time, you don't need to build the distribution yourself. You can simply modify the code, then test via:

% prove -l

If you want to build the distribution (e.g. to try to install it locally on your system), you can install Dist::Zilla, Dist::Zilla::PluginBundle::Author::PERLANCAR, Pod::Weaver::PluginBundle::Author::PERLANCAR, and sometimes one or two other Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond that are considered a bug and can be reported to me.

COPYRIGHT AND LICENSE

This software is copyright (c) 2026 by perlancar <perlancar@cpan.org>.

This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.

BUGS

Please report any bugs or feature requests on the bugtracker website https://rt.cpan.org/Public/Dist/Display.html?Name=Desktop-KDE-Util

When submitting a bug or request, please include a test-file or a patch to an existing test-file that illustrates the bug or desired feature.